@@ -1,5 +1,5 @@
 # emacs: -*- mode: python; py-indent-offset: 4; tab-width: 4; indent-tabs-mode: nil -*-
-# ex: set sts=4 ts=4 sw=4 noet:
+# ex: set sts=4 ts=4 sw=4 et:
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the datalad package for the
@@ -10,6 +10,14 @@
 
 """
 
+from datalad.downloaders.credentials import (
+    AWS_S3,
+    LORIS_Token,
+    NDA_S3,
+    Token,
+    UserPassword,
+    GitCredential)
+
 __docformat__ = 'restructuredtext'
 
 from logging import getLogger
@@ -18,3 +26,11 @@ lgr = getLogger('datalad.providers')
 # TODO: we might not need to instantiate it right here
 # lgr.debug("Initializing data providers credentials interface")
 # providers = Providers().from_config_files()
+CREDENTIAL_TYPES = {
+    'user_password': UserPassword,
+    'aws-s3': AWS_S3,
+    'nda-s3': NDA_S3,
+    'token': Token,
+    'loris-token': LORIS_Token,
+    'git': GitCredential,
+}
