@@ -1,5 +1,5 @@
 # emacs: -*- mode: python; py-indent-offset: 4; tab-width: 4; indent-tabs-mode: nil -*-
-# ex: set sts=4 ts=4 sw=4 noet:
+# ex: set sts=4 ts=4 sw=4 et:
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the datalad package for the
@@ -13,11 +13,18 @@ import logging
 import os
 import os.path as op
 
-from .runner import WitlessRunner
-from .utils import (
-    borrowdoc,
+from typing import Optional
+
+from datalad.dochelpers import borrowdoc
+from datalad.utils import (
     generate_file_chunks,
+    make_tempfile,
 )
+from .runner import (
+    GeneratorMixIn,
+    WitlessRunner,
+)
+
 
 lgr = logging.getLogger('datalad.runner.gitrunner')
 
@@ -118,6 +125,9 @@ class GitWitlessRunner(WitlessRunner, GitRunnerBase):
     See GitRunnerBase it mixes in for more details
     """
 
+    # Behavior option to load up from config upon demand
+    _CFG_PATHSPEC_FROM_FILE = None
+
     @borrowdoc(WitlessRunner)
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -133,9 +143,64 @@ class GitWitlessRunner(WitlessRunner, GitRunnerBase):
             copy=False,
         )
 
-    def run_on_filelist_chunks(self, cmd, files, protocol=None,
-                               cwd=None, env=None, **kwargs):
-        """Run a git-style command multiple times if `files` is too long
+    def _get_chunked_results(self,
+                             cmd,
+                             files,
+                             *,
+                             protocol=None,
+                             cwd=None,
+                             env=None,
+                             pathspec_from_file: Optional[bool] = False,
+                             **kwargs):
+
+        assert isinstance(cmd, list)
+
+        if self._CFG_PATHSPEC_FROM_FILE is None:
+            from datalad import cfg  # avoid circular import
+            GitWitlessRunner._CFG_PATHSPEC_FROM_FILE = cfg.obtain('datalad.runtime.pathspec-from-file')
+            assert GitWitlessRunner._CFG_PATHSPEC_FROM_FILE in ('multi-chunk', 'always')
+        file_chunks = list(generate_file_chunks(files, cmd))
+
+        if pathspec_from_file and (len(file_chunks) > 1 or GitWitlessRunner._CFG_PATHSPEC_FROM_FILE == 'always'):
+            # if git supports pathspec---from-file and we need multiple chunks to do,
+            # just use --pathspec-from-file
+            with make_tempfile(content=b'\x00'.join(f.encode() for f in files)) as tf:
+                cmd += ['--pathspec-file-nul', f'--pathspec-from-file={tf}']
+                yield self.run(
+                    cmd=cmd,
+                    protocol=protocol,
+                    cwd=cwd,
+                    env=env,
+                    **kwargs)
+                return
+
+        # "classical" chunking
+        for i, file_chunk in enumerate(file_chunks):
+            # do not pollute with message when there only ever is a single chunk
+            if len(file_chunk) < len(files):
+                lgr.debug(
+                    'Process file list chunk %i (length %i)', i, len(file_chunk))
+
+            yield self.run(
+                cmd=cmd + ['--'] + file_chunk,
+                protocol=protocol,
+                cwd=cwd,
+                env=env,
+                **kwargs)
+
+    def run_on_filelist_chunks(self,
+                                cmd,
+                                files,
+                                *,
+                                protocol=None,
+                                cwd=None,
+                                env=None,
+                                pathspec_from_file: Optional[bool] = False,
+                                **kwargs):
+        """
+        Run a git-style command multiple times if `files` is too long,
+        using a non-generator protocol, i.e. a protocol that is not
+        derived from `datalad.runner.protocol.GeneratorMixIn`.
 
         Parameters
         ----------
@@ -157,6 +222,10 @@ class GitWitlessRunner(WitlessRunner, GitRunnerBase):
           This must be a complete environment definition, no values
           from the current environment will be inherited. Overrides
           any `env` given to the constructor.
+        pathspec_from_file : bool, optional
+          Could be set to True for a `git` command which supports
+          --pathspec-from-file and --pathspec-file-nul options. Then pathspecs
+          would be passed through a temporary file.
         kwargs :
           Passed to the Protocol class constructor.
 
@@ -177,24 +246,61 @@ class GitWitlessRunner(WitlessRunner, GitRunnerBase):
         FileNotFoundError
           When a given executable does not exist.
         """
-        assert isinstance(cmd, list)
-        file_chunks = generate_file_chunks(files, cmd)
+
+        assert not issubclass(protocol, GeneratorMixIn), \
+            "cannot use GitWitlessRunner.run_on_filelist_chunks() " \
+            "with a protocol that inherits GeneratorMixIn, use " \
+            "GitWitlessRunner.run_on_filelist_chunks_items_() instead"
 
         results = None
-        for i, file_chunk in enumerate(file_chunks):
-            # do not pollute with message when there only ever is a single chunk
-            if len(file_chunk) < len(files):
-                lgr.debug('Process file list chunk %i (length %i)',
-                          i, len(file_chunk))
-            res = self.run(
-                cmd + ['--'] + file_chunk,
-                protocol=protocol,
-                cwd=cwd,
-                env=env,
-                **kwargs)
+        for res in self._get_chunked_results(cmd=cmd,
+                                             files=files,
+                                             protocol=protocol,
+                                             cwd=cwd,
+                                             env=env,
+                                             pathspec_from_file=pathspec_from_file,
+                                             **kwargs):
             if results is None:
                 results = res
             else:
                 for k, v in res.items():
                     results[k] += v
         return results
+
+    def run_on_filelist_chunks_items_(self,
+                                      cmd,
+                                      files,
+                                      *,
+                                      protocol=None,
+                                      cwd=None,
+                                      env=None,
+                                      pathspec_from_file: Optional[bool] = False,
+                                      **kwargs):
+        """
+        Run a git-style command multiple times if `files` is too long,
+        using a generator protocol, i.e. a protocol that is
+        derived from `datalad.runner.protocol.GeneratorMixIn`.
+
+        Parameters
+        ----------
+        see GitWitlessRunner.run_on_filelist_chunks() for a definition
+        of parameters
+
+        Returns
+        -------
+        Generator that yields output of the cmd
+        """
+
+        assert issubclass(protocol, GeneratorMixIn), \
+            "cannot use GitWitlessRunner.run_on_filelist_chunks_items_() " \
+            "with a protocol that does not inherits GeneratorMixIn, use " \
+            "GitWitlessRunner.run_on_filelist_chunks() instead"
+
+        for chunk_generator in self._get_chunked_results(cmd=cmd,
+                                                         files=files,
+                                                         protocol=protocol,
+                                                         cwd=cwd,
+                                                         env=env,
+                                                         pathspec_from_file=pathspec_from_file,
+                                                         **kwargs):
+            yield from chunk_generator
