@@ -1,5 +1,5 @@
 # emacs: -*- mode: python; py-indent-offset: 4; tab-width: 4; indent-tabs-mode: nil -*-
-# ex: set sts=4 ts=4 sw=4 noet:
+# ex: set sts=4 ts=4 sw=4 et:
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the datalad package for the
@@ -10,12 +10,8 @@
 """
 
 from collections import OrderedDict
-from six import PY2
 
-if PY2:
-    from ._lru_cache2 import lru_cache
-else:
-    from functools import lru_cache
+from functools import lru_cache
 
 
 # based on http://stackoverflow.com/a/2437645/1265472
