@@ -135,6 +135,9 @@ from datalad.utils import (
 )
 
 
+_GIT_ANNEX_VERSIONS_INFO = AnnexRepo.check_repository_versions()
+
+
 @assert_cwd_unchanged
 @with_tempfile
 @with_tempfile
@@ -1290,30 +1293,52 @@ def test_annex_remove(path=None):
 @with_tempfile
 @with_tempfile
 @with_tempfile
-def test_repo_version(path1=None, path2=None, path3=None):
+def test_repo_version_upgrade(path1=None, path2=None, path3=None):
     with swallow_logs(new_level=logging.INFO) as cm:
-        annex = AnnexRepo(path1, create=True, version=6)
-        assert_repo_status(path1, annex=True)
-        version = int(annex.config.get('annex.version'))
         # Since git-annex 7.20181031, v6 repos upgrade to v7.
-        supported_versions = AnnexRepo.check_repository_versions()["supported"]
-        v6_lands_on = next(i for i in supported_versions if i >= 6)
-        eq_(version, v6_lands_on)
+        # Future proofing: We will test on v6 as long as it is upgradeable,
+        # but would switch to first upgradeable after
+        Uversion = 6 if 6 in _GIT_ANNEX_VERSIONS_INFO["upgradable"] \
+            else _GIT_ANNEX_VERSIONS_INFO["upgradeable"][0]
+        v_first_supported = next(i for i in _GIT_ANNEX_VERSIONS_INFO["supported"] if i >= Uversion)
+        annex = AnnexRepo(path1, create=True, version=Uversion)
+        assert_repo_status(path1, annex=True)
+        v_upgraded_to = int(annex.config.get('annex.version'))
 
-        assert_in("will be upgraded to 8", cm.out)
+        if external_versions['cmd:annex'] <= '10.20220724':
+            eq_(v_upgraded_to, v_first_supported)
+            assert_in("will be upgraded to 8", cm.out)
+        else:
+            # 10.20220724-5-g63cef2ae0 started to auto-upgrade to 10, although 8 was the
+            # lowest supported. In general we can only assert that we upgrade into one
+            # of the supported
+            assert_in(v_upgraded_to, _GIT_ANNEX_VERSIONS_INFO["supported"])
+            assert_in("will be upgraded to %s or later version" % v_first_supported, cm.out)
 
     # default from config item (via env var):
-    with patch.dict('os.environ', {'DATALAD_REPO_VERSION': '6'}):
+    with patch.dict('os.environ', {'DATALAD_REPO_VERSION': str(Uversion)}):
+        # and check consistency of upgrading to the default version:
         annex = AnnexRepo(path2, create=True)
         version = int(annex.config.get('annex.version'))
-        eq_(version, v6_lands_on)
+        eq_(version, v_upgraded_to)
 
-        # Assuming specified version is a supported version...
-        if 5 in supported_versions:
+
+@pytest.mark.parametrize("version", _GIT_ANNEX_VERSIONS_INFO["supported"])
+def test_repo_version_supported(version, tmp_path):
+        # default from config item (via env var):
+        Uversion = _GIT_ANNEX_VERSIONS_INFO["upgradable"][0]
+        with patch.dict('os.environ', {'DATALAD_REPO_VERSION': str(Uversion)}):
             # ...parameter `version` still has priority over default config:
-            annex = AnnexRepo(path3, create=True, version=5)
-            version = int(annex.config.get('annex.version'))
-            eq_(version, 5)
+            annex = AnnexRepo(str(tmp_path), create=True, version=version)
+            annex_version = int(annex.config.get('annex.version'))
+            if not annex.is_managed_branch():
+                # There is no "upgrade" for any of the supported versions.
+                # if we are not in adjusted branch
+                eq_(annex_version, version)
+            else:
+                print("HERE")
+                # some annex command might have ran to trigger the update
+                assert annex_version in {v for v in _GIT_ANNEX_VERSIONS_INFO["supported"] if v >= version}
 
 
 @skip_if(external_versions['cmd:annex'] > '8.20210428', "Stopped showing if too quick")
@@ -2409,7 +2434,7 @@ def test_files_split(topdir=None, *, cls):
         os.unlink(f)
         with open(f, 'w') as f:
             f.write('1')
-    dl.save(dataset=r.path, path=dirs)
+    dl.save(dataset=r.path, path=dirs, result_renderer="disabled")
 
 
 @skip_if_on_windows
