@@ -10,35 +10,32 @@
 
 import os.path as op
 from pathlib import Path
-import datalad.utils as ut
 
-from datalad.tests.utils import (
+import datalad.utils as ut
+from datalad.distribution.dataset import Dataset
+from datalad.support.exceptions import NoSuchPathError
+from datalad.support.gitrepo import GitRepo
+from datalad.tests.utils_pytest import (
     assert_dict_equal,
     assert_equal,
     assert_false,
     assert_in,
     assert_not_in,
     assert_raises,
+    assert_repo_status,
     get_annexstatus,
+    get_convoluted_situation,
     known_failure_githubci_win,
     slow,
     with_tempfile,
     with_tree,
 )
 
-from datalad.distribution.dataset import Dataset
-from datalad.support.exceptions import NoSuchPathError
-from datalad.support.gitrepo import GitRepo
-from datalad.tests.utils import (
-    assert_repo_status,
-    get_convoluted_situation,
-)
-
 
 @slow  # 10sec on travis
 @known_failure_githubci_win
 @with_tempfile
-def test_get_content_info(path):
+def test_get_content_info(path=None):
     repo = GitRepo(path)
     assert_equal(repo.get_content_info(), {})
     # an invalid reference causes an exception
@@ -156,7 +153,7 @@ def test_get_content_info(path):
 
 
 @with_tempfile
-def test_compare_content_info(path):
+def test_compare_content_info(path=None):
     # TODO remove when `create` is RF to return the new Dataset
     ds = Dataset(path).create()
     assert_repo_status(path)
@@ -173,7 +170,7 @@ def test_compare_content_info(path):
 
 
 @with_tempfile
-def test_subds_path(path):
+def test_subds_path(path=None):
     # a dataset with a subdataset with a file, all neatly tracked
     ds = Dataset(path).create()
     subds = ds.create('sub')
@@ -194,7 +191,7 @@ def test_subds_path(path):
 
 
 @with_tempfile
-def test_report_absent_keys(path):
+def test_report_absent_keys(path=None):
     ds = Dataset(path).create()
     # create an annexed file
     testfile = ds.pathobj / 'dummy'
@@ -217,7 +214,7 @@ def test_report_absent_keys(path):
         assert_in(testfile, ai)
         assert_equal(ai[testfile]['has_content'], True)
     # drop the key, not available anywhere else
-    ds.drop('dummy', check=False)
+    ds.drop('dummy', reckless='kill')
     # does not change a thing, except the key is gone
     for ai in (
             ds.repo.get_content_annexinfo(eval_availability=True),
@@ -234,7 +231,7 @@ def test_report_absent_keys(path):
         assert_in(testfile, ai)
         assert_equal(ai[testfile]['has_content'], False)
     # make sure files with URL keys are correctly reported:
-    from datalad import test_http_server
+    from datalad.conftest import test_http_server
     remote_file_name = 'imaremotefile.dat'
     local_file_name = 'mehasurlkey'
     (Path(test_http_server.path) / remote_file_name).write_text("weee")
@@ -253,7 +250,7 @@ def test_report_absent_keys(path):
 
 
 @with_tempfile
-def test_annexinfo_init(path):
+def test_annexinfo_init(path=None):
     ds = Dataset(path).create()
     foo = ds.pathobj / "foo"
     foo_cont = b"foo content"
@@ -284,7 +281,7 @@ def test_annexinfo_init(path):
 
 
 @with_tempfile
-def test_info_path_inside_submodule(path):
+def test_info_path_inside_submodule(path=None):
     ds = Dataset(path).create()
     subds = ds.create("submod")
     foo = (subds.pathobj / "foo")
@@ -296,7 +293,7 @@ def test_info_path_inside_submodule(path):
 
 
 @with_tempfile
-def test_get_content_info_dotgit(path):
+def test_get_content_info_dotgit(path=None):
     ds = Dataset(path).create()
     # Files in .git/ won't be reported, though this takes a kludge on our side
     # before Git 2.25.
@@ -304,7 +301,7 @@ def test_get_content_info_dotgit(path):
 
 
 @with_tempfile
-def test_get_content_info_paths_empty_list(path):
+def test_get_content_info_paths_empty_list(path=None):
     ds = Dataset(path).create()
 
     # Unlike None, passing any empty list as paths to get_content_info() does
@@ -330,7 +327,7 @@ def test_get_content_info_paths_empty_list(path):
 
 
 @with_tempfile
-def test_status_paths_empty_list(path):
+def test_status_paths_empty_list(path=None):
     ds = Dataset(path).create()
     assert_equal(ds.repo.status(paths=[]), {})
 
@@ -339,12 +336,12 @@ def test_status_paths_empty_list(path):
                  ('inannex.txt', 'inannex'),
                  ('dir1', {'dropped': 'dropped'}),
                  ('dir2', {'d21': 'd21', 'd22': 'd22'})))
-def test_get_file_annexinfo(path):
+def test_get_file_annexinfo(path=None):
     ds = Dataset(path).create(force=True)
     ds.save('ingit.txt', to_git=True)
     ds.save()
     # have some content-less component for testing
-    ds.drop(ds.pathobj / 'dir1', check=False)
+    ds.drop(ds.pathobj / 'dir1', reckless='kill')
 
     repo = ds.repo
     # only handles a single file at a time
