@@ -1,5 +1,5 @@
 # emacs: -*- mode: python; py-indent-offset: 4; tab-width: 4; indent-tabs-mode: nil -*-
-# ex: set sts=4 ts=4 sw=4 noet:
+# ex: set sts=4 ts=4 sw=4 et:
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the datalad package for the
@@ -8,9 +8,11 @@
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 """Tests for vcr adapter"""
 
+from ...tests.utils_pytest import (
+    SkipTest,
+    eq_,
+)
 from ..vcr_ import use_cassette
-from ...tests.utils import SkipTest
-from ...tests.utils import eq_
 
 
 def test_use_cassette_if_no_vcr():
