@@ -288,6 +288,24 @@ def test_something(path=None, new_home=None):
     assert_equal(cfg.get('datalad.godgiven'), True)
 
 
+@with_tree(tree={
+    '.gitconfig': """\
+[includeIf "gitdir:**/devbgc/**"]
+    path = ~/.gitconfig_bgc
+
+[custom "datalad"]
+  variable = value
+"""})
+def test_includeif_breaking(new_home=None):
+    patched_env = os.environ.copy()
+    patched_env.pop('GIT_CONFIG_GLOBAL', None)
+    patched_env.update(get_home_envvars(new_home))
+    with patch.dict('os.environ', patched_env, clear=True):
+        cfg = ConfigManager()
+        # just want to make sure we read it and didn't crash
+        assert cfg.get('custom.datalad.variable') == "value"
+
+
 @with_tree(tree={
     'ds': {
         '.datalad': {
@@ -703,6 +721,7 @@ def test_write_config_section(path=None):
     # can we handle a bare repo?
     gr = GitRepo(path, create=True, bare=True)
 
+    obscure = "ds-; &%b5{}# some % "
     # test cases
     # first 3 args are write_config_section() parameters
     # 4th arg is a list with key/value pairs that should end up in a
@@ -719,6 +738,12 @@ def test_write_config_section(path=None):
         ('short', ' s p a c e ', {"a123": ' space all over '}, [
             ('short. s p a c e .a123', ' space all over '),
         ]),
+        ('submodule', obscure, {
+            'path': obscure,
+            'url': f"./{obscure}"}, [
+            (f"submodule.{obscure}.path", obscure),
+            (f"submodule.{obscure}.url", f"./{obscure}"),
+        ]),
     ]
 
     for tc in testcfg:
