@@ -83,7 +83,6 @@ from datalad.tests.utils_pytest import (
     skip_wo_symlink_capability,
     swallow_logs,
     with_tempfile,
-    with_testrepos,
     with_testsui,
     with_tree,
     without_http_proxy,
@@ -126,7 +125,6 @@ def test_nested_with_tempfile_basic(f1=None, f2=None):
 @with_tree((('f1.txt', 'load'),))
 @with_tempfile(suffix='.cfg')
 @with_tempfile(suffix='.cfg.old')
-@with_testrepos(flavors=local_testrepo_flavors, count=1)
 def check_nested_with_tempfile_parametrized_surrounded(
         param, f0=None, tree=None, f1=None, f2=None, repo=None):
     eq_(param, "param1")
@@ -136,7 +134,7 @@ def check_nested_with_tempfile_parametrized_surrounded(
     ok_(f1 != f2)
     ok_(f1.endswith('.cfg'), msg="got %s" % f1)
     ok_(f2.endswith('.cfg.old'), msg="got %s" % f2)
-    ok_(repo)  # got some repo -- local or url
+
 
 
 def test_nested_with_tempfile_parametrized_surrounded():
@@ -160,27 +158,6 @@ def test_with_tempfile_content_raises_on_mkdir():
         t()
 
 
-def test_with_testrepos():
-    repos = []
-
-    @with_testrepos
-    def check_with_testrepos(repo):
-        repos.append(repo)
-
-    check_with_testrepos()
-
-    eq_(len(repos),
-        2 if on_windows  # TODO -- would fail now in DATALAD_TESTS_NONETWORK mode
-          else (15 if dl_cfg.get('datalad.tests.nonetwork') else 16))  # local, local-url, clone, network
-
-    for repo in repos:
-        if not (repo.startswith('git://') or repo.startswith('http')):
-            # either it is a "local" or a removed clone
-            ok_(exists(opj(repo, '.git'))
-                or
-                not exists(opj(repo, '.git', 'remove-me')))
-
-
 def test_get_resolved_values():
     from datalad.tests.utils_pytest import _get_resolved_flavors
     flavors = ['networkish', 'local']
@@ -191,12 +168,6 @@ def test_get_resolved_values():
     with patch_config({'datalad.tests.nonetwork': '1'}):
         eq_(_get_resolved_flavors(flavors), ['local'])
 
-        # and one more to see the exception being raised if nothing to teston
-        @with_testrepos(flavors=['network'])
-        def magical():
-            raise AssertionError("Must not be ran")
-        assert_raises(Skipped, magical)
-
 def test_with_tempfile_mkdir():
     dnames = []  # just to store the name within the decorated function
 
